function merge(tbls)
	local res = {}
	for i,v in ipairs(tbls) do
		for i2,v2 in ipairs(v) do
			table.insert(res,v2)
		end
	end
	
	return res
end

function allExcept(tbls, except)
	local tomerge = {}
	for i,v in pairs(tbls) do
		if i~=except then
			table.insert(tomerge, v)
		end
	end
	return merge(tomerge)
end

--list of upgrades from created groups, hidden on planner, mfd; late activation
upgrades = {
	smallAirfield = {
		blue = {'blueGroup1','blueGroup2','blueGroup4','blueGroup5'},
		red = {'redGroup1','redGroup2','redGroup4','redGroup5'}
	},
	smallAirfieldSAM = {
		blue = {'blueGroup3','blueGroup1','blueGroup2','blueGroup5'},
		red = {'redGroup3','redGroup1','redGroup2','redGroup5'}
	},
	largeAirfield = {
		blue = {'blueGroup1','blueGroup2','blueGroup4','blueGroup5', 'blueGroup3', 'blueGroup5'},
		red = {'redGroup1','redGroup2','redGroup4','redGroup5', 'redGroup3', 'redGroup5'}
	},
	smallSAMSite = {
		blue = {'blueGroup1','blueSmallSAM', 'blueGroup2', 'blueGroup4', 'blueGroup5', 'blueGroup4'},
		red = {'redGroup1','redSmallSAM', 'redGroup2', 'redGroup4', 'redGroup5', 'redGroup4'}
	},
	largeSAMSite = {
		blue = {'blueGroup4','blueLargeSAM', 'blueGroup2', 'blueGroup1', 'blueGroup3', 'blueGroup5'},
		red = {'redGroup4', 'redGroup2', 'redGroup1', 'redLargeSAM', 'redGroup3', 'redGroup5'}
	},
	farp = {
		blue = {'blueGroup3'},
		red = {}
	},
	carrierGroup = {
		blue = {'blueCarrierGroupInvis'},
		red = {}
	}
}

--list of waypoints with specific data for specials
flavor = {
	bengurion = 'WPT 1\nStart zone',
	sdedov = 'WPT 2\nHidden Easter Egg, destroy for 500 immediate credits',
	palmahim = 'WPT 3\n',
	telnof = 'WPT 4\n',
	hatzor = 'WPT 5\nHidden Easter Egg, destroy for 500 immediate credits',
	nevatim = 'WPT 6\n',
	ramonairbase = 'WPT 7\n',
	farprome = 'WPT 8\n',
	ovda = 'WPT 9\n',
	campxray = 'WPT 10\n',
	stcatherine = 'WPT 11\n',
	aburedeis = 'WPT 12\n',
	birhasanah = 'WPT 13\n',
	melez = 'WPT 14\n',
	baluza = 'WPT 15\n',
	kibritairbase = 'WPT 16\n',
	abusawayr = 'WPT 17\n',
	assalihiyah = 'WPT 18\n',
	almansurah = 'WPT 19\n',
	bilbeisairbase = 'WPT 20\n',
	wadialjandali = 'WPT 21\n',
	cairointl = 'WPT 22\n',
	cairowest = 'WPT 23\n',
	carrierGroup = 'Carrier Group\n'
}

--persistence data
local filepath = 'Raiders_696CW_Foothold_Sinai.miz'
if lfs then 
	local dir = lfs.writedir()..'Missions/Saves/'
	lfs.mkdir(dir)
	filepath = dir..filepath
	env.info('Foothold - Save file path: '..filepath)
end

pathofFile = filepath

--list of zones with who owns them starting off and their level of items: 0 = neutral, 1 = red, 2 = blue
bc = BattleCommander:new(filepath, 10, 60)
zones = {
	bengurion = ZoneCommander:new({zone='Ben-Gurion', side=2, level=6, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.bengurion}), --6x  6
	sdedov = ZoneCommander:new({zone='Sde Dov', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.sdedov}), --4x  4
	palmahim = ZoneCommander:new({zone='Palmahim', side=1, level=4, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.palmahim}), --4x  4
	telnof = ZoneCommander:new({zone='Tel Nof', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.telnof}), --4x  4
	hatzor = ZoneCommander:new({zone='Hatzor', side=1, level=4, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.hatzor}), --4x  4
	nevatim = ZoneCommander:new({zone='Nevatim', side=1, level=2, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.nevatim}), --6x  1
	ramonairbase = ZoneCommander:new({zone='Ramon Airbase', side=1, level=2, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.ramonairbase}), --6x  2
	farprome = ZoneCommander:new({zone='FARP Rome', side=0, level=1, upgrades=upgrades.farp, crates={}, flavorText=flavor.farprome}), --1x  1
	ovda = ZoneCommander:new({zone='Ovda', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.ovda}), --6x  4
	campxray = ZoneCommander:new({zone='Camp X-Ray', side=1, level=4, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.campxray}), --4x  4
	stcatherine = ZoneCommander:new({zone='St Catherine', side=1, level=1, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.stcatherine}), --6x  1
	aburedeis = ZoneCommander:new({zone='Abu Rudeis', side=1, level=3, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.aburedeis}), --4x  3
	birhasanah = ZoneCommander:new({zone='Bir Hasanah', side=1, level=2, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.birhasanah}), --6x  2
	melez = ZoneCommander:new({zone='Melez', side=1, level=2, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.melez}), --6x  2
	baluza = ZoneCommander:new({zone='Baluza', side=1, level=2, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.baluza}), --4x  3
	kibritairbase = ZoneCommander:new({zone='Kibrit Air Base', side=1, level=2, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.kibritairbase}), --6x  4
	abusawayr = ZoneCommander:new({zone='Abu Suwayr', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.abusawayr}), --6x  4
	assalihiyah = ZoneCommander:new({zone='As Salihiyah', side=1, level=2, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.assalihiyah}), --4x  2
	almansurah = ZoneCommander:new({zone='Al Mansurah', side=1, level=2, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.almansurah}), --4x  2
	bilbeisairbase = ZoneCommander:new({zone='Bilbeis Air Base', side=1, level=2, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.bilbeisairbase}), --4x  2
	wadialjandali = ZoneCommander:new({zone='Wadi al Jandali', side=1, level=2, upgrades=upgrades.smallAirfieldSAM, crates={}, flavorText=flavor.wadialjandali}), --4x  2
	cairointl = ZoneCommander:new({zone='Cairo Intl', side=1, level=1, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.cairointl}), --6x  1
	cairowest = ZoneCommander:new({zone='Cairo West', side=1, level=1, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.cairowest}), --6x  1
	carrierGroup = ZoneCommander:new({zone='Carrier Group', side=2, level=1, upgrades=upgrades.carrierGroup, crates={}, flavorText=flavor.carrierGroup}),
}

-- add unit groups to zones
zones.bengurion:addGroups({
	GroupCommander:new({name='blueBenGurionPatrol', mission='patrol', targetzone='Ben-Gurion'})
})

zones.carrierGroup:addGroups({
	GroupCommander:new({name='blueCarrierGroupBenGurionSupply', mission='supply', targetzone='Ben-Gurion'}),
	GroupCommander:new({name='blueCarrierGroupBenGurionSupply', mission='supply', targetzone='Baluza'})
})

zones.palmahim:addGroups({
	GroupCommander:new({name='redpalmahimbengurionAttack', mission='attack', targetzone='Ben-Gurion', type='surface'})
})

zones.hatzor:addGroups({
	GroupCommander:new({name='redhatzorpalmahimAttack', mission='attack', targetzone='Palmahim', type='surface'}),
	GroupCommander:new({name='redhatzorsdedovAttack', mission='attack', targetzone='Sde Dov', type='surface'}),
	GroupCommander:new({name='redhatzorbengurionAttack', mission='attack', targetzone='Ben-Gurion'})
})

zones.nevatim:addGroups({
	GroupCommander:new({name='rednevatimPatrol', mission='patrol', targetzone='Nevatim'}),
	GroupCommander:new({name='rednevatimhatzorAttack', mission='attack', targetzone='Hatzor'}),
	GroupCommander:new({name='rednevatimtelnofAttack', mission='attack', targetzone='Tel Nof'}),
	GroupCommander:new({name='rednevatimbengurionAttack', mission='attack', targetzone='Ben-Gurion'}),
	GroupCommander:new({name='rednevatimbengurionAttack-1', mission='attack', targetzone='Ben-Gurion'}),
	GroupCommander:new({name='redNevatimSdeDovSupply', mission='supply', targetzone='Sde Dov'}),
	GroupCommander:new({name='redNevatimPalmahimSupply', mission='supply', targetzone='Palmahim'}),
	GroupCommander:new({name='redNevatimHatzorSupply', mission='supply', targetzone='Hatzor'}),
	GroupCommander:new({name='redNevatimRamonAirbaseSupply', mission='supply', targetzone='Ramon Airbase'}),
	GroupCommander:new({name='blueNevatimOvdaSupply', mission='supply', targetzone='Ovda'}),
	GroupCommander:new({name='blueNevatimRamonAirbaseSupply', mission='supply', targetzone='Ramon Airbase'})
})

zones.ramonairbase:addGroups({
	GroupCommander:new({name='redramonPatrol', mission='patrol', targetzone='Ramon Airbase'}),
	GroupCommander:new({name='blueRamonAirbasePatrol', mission='patrol', targetzone='Ramon Airbase'}),
	GroupCommander:new({name='redramonnevatimAttack', mission='attack', targetzone='Nevatim'}),
	GroupCommander:new({name='blueRamonAirbaseOvdaSupply', mission='supply', targetzone='Ovda'}),
	GroupCommander:new({name='redRamonAirbaseNevatimSupply', mission='supply', targetzone='Nevatim'}),
	GroupCommander:new({name='blueRamonAirbaseNevatimSupply', mission='supply', targetzone='Nevatim'})
})

zones.ovda:addGroups({
	GroupCommander:new({name='redovdaPatrol', mission='patrol', targetzone='Ovda'}),
	GroupCommander:new({name='redovdabengurionAttack', mission='attack', targetzone='Ben-Gurion'}),
	GroupCommander:new({name='redovdaramonAttack', mission='attack', targetzone='Ramon Airbase', type='surface'}),
	GroupCommander:new({name='redovdanevatimAttack', mission='attack', targetzone='Nevatim', type='surface'})
})

zones.campxray:addGroups({
	GroupCommander:new({name='blueCampXRayStCatherineSupply', mission='supply', targetzone='St Catherine'}),
	GroupCommander:new({name='redCampXRayStCatherineSupply', mission='supply', targetzone='St Catherine'})
})

zones.stcatherine:addGroups({
	GroupCommander:new({name='redstcatherinePatrol', mission='patrol', targetzone='St Catherine'}),
	GroupCommander:new({name='redstcatherineovdaAttack', mission='attack', targetzone='Ovda', type='surface'}),
	GroupCommander:new({name='redStCatherineAbuRudeisSupply', mission='supply', targetzone='Abu Rudeis'}),
	GroupCommander:new({name='blueStCatherineAbuRudeisSupply', mission='supply', targetzone='Abu Rudeis'}),
	GroupCommander:new({name='redStCatherineCampXraySupply', mission='supply', targetzone='Camp X-Ray'}),
	GroupCommander:new({name='blueStCatherineXRaySupply', mission='supply', targetzone='Camp X-Ray'})
	
})

zones.aburedeis:addGroups({
	GroupCommander:new({name='redaburedeisstcatherineAttack', mission='attack', targetzone='St Catherine'}),
	GroupCommander:new({name='redaburudeisPatrol', mission='patrol', targetzone='Abu Rudeis'})
})		

zones.melez:addGroups({
	GroupCommander:new({name='redmelezPatrol', mission='patrol', targetzone='Melez'}),
	GroupCommander:new({name='blueMelezPatrol', mission='patrol', targetzone='Melez'}),
	GroupCommander:new({name='redmelezramonAttack', mission='attack', targetzone='Ramon Airbase'}),
	GroupCommander:new({name='redmeleznevatimAttack', mission='attack', targetzone='Nevatim'}),
	GroupCommander:new({name='redMelezBirHasanahSupply', mission='supply', targetzone='Bir Hasanah'}),
	GroupCommander:new({name='redMelezBaluzaSupply', mission='supply', targetzone='Baluza'}),
	GroupCommander:new({name='redMelezKibritAirbaseSupply', mission='supply', targetzone='Kibrit Air Base'}),
	GroupCommander:new({name='blueMelezBirHasanahSupply', mission='supply', targetzone='Bir Hasanah'}),
	GroupCommander:new({name='blueMelezBaluzaSupply', mission='supply', targetzone='Baluza'}),
	GroupCommander:new({name='blueMelezKibritAirbaseSupply', mission='supply', targetzone='Kibrit Air Base'}),
	GroupCommander:new({name='redMelezOvdaSupply', mission='supply', targetzone='Ovda'}),
	GroupCommander:new({name='redMelezRamonAirbaseSupply', mission='supply', targetzone='Ramon Airbase'})
})

zones.baluza:addGroups({
	GroupCommander:new({name='redbaluzamelezAttack', mission='attack', targetzone='Melez', type='surface'}),
	GroupCommander:new({name='redbaluzabirhasanahAttack', mission='attack', targetzone='Bir Hasanah', type='surface'})
})

zones.kibritairbase:addGroups({
	GroupCommander:new({name='redkibritmelezAttack', mission='attack', targetzone='Melez'}),
	GroupCommander:new({name='redkibritbirhasanahAttack', mission='attack', targetzone='Bir Hasanah'}),
	GroupCommander:new({name='redKibritAirbaseAbuSuwayrSupply', mission='supply', targetzone='Abu Suwayr'}),
	GroupCommander:new({name='redKibritAirbaseBilbeisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='redKibritAirbaseWadiAlJandaliSupply', mission='supply', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='redKibritAirbaseBirHasanahSupply', mission='supply', targetzone='Bir Hasanah'}),
	GroupCommander:new({name='blueKibritAirbaseAbuSuwayrSupply', mission='supply', targetzone='Abu Suwayr'}),
	GroupCommander:new({name='blueKibritAirbaseBilbeisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='blueKibritAirbaseWadiAlJandaliSupply', mission='supply', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='blueKibritAirbaseBirHasanahSupply', mission='supply', targetzone='Bir Hasanah'}),
	GroupCommander:new({name='redKibritAirbaseMelezSupply', mission='supply', targetzone='Melez'}),
	GroupCommander:new({name='blueKibritAirbaseMelezSupply', mission='supply', targetzone='Melez'})
	
})

zones.almansurah:addGroups({
	GroupCommander:new({name='redalmansurahPatrol-1', mission='patrol', targetzone='Al Mansurah'}),
	GroupCommander:new({name='redalmansurahPatrol-2', mission='patrol', targetzone='Al Mansurah'}),
	GroupCommander:new({name='redAlMansurahAsSalihiyahSupply', mission='supply', targetzone='As Salihiyah'}),
	GroupCommander:new({name='redAlMansurahBilbeisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='redAlMansurahCairoIntlSupply', mission='supply', targetzone='Cairo Intl'}),
	GroupCommander:new({name='redAlMansurahCairoWestSupply', mission='supply', targetzone='Cairo West'}),
	GroupCommander:new({name='redAlMansurahBaluzaSupply', mission='supply', targetzone='Baluza'}),
	GroupCommander:new({name='blueAlMansurahAsSalihiyahSupply', mission='supply', targetzone='As Salihiyah'}),
	GroupCommander:new({name='blueAlMansurahBilbeisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='blueAlMansurahCairoIntlSupply', mission='supply', targetzone='Cairo Intl'}),
	GroupCommander:new({name='blueAlMansurahCairoWestSupply', mission='supply', targetzone='Cairo West'}),
	GroupCommander:new({name='blueAlMansurahBaluzaSupply', mission='supply', targetzone='Baluza'})
})

zones.bilbeisairbase:addGroups({
	GroupCommander:new({name='redbelbeiskibritAttack', mission='attack', targetzone='Kibrit Air Base'}),
	GroupCommander:new({name='redbilbeisabusawayrAttack', mission='attack', targetzone='Abu Suwayr'}),
	GroupCommander:new({name='redbilbeisassalihiyahAttack', mission='attack', targetzone='As Salihiyah'})
})

zones.wadialjandali:addGroups({
	GroupCommander:new({name='redwadialjandaliPatrol', mission='patrol', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='blueWadiAlJandaliPatrol', mission='patrol', targetzone='Wadi al Jandali'})
})

zones.cairointl:addGroups({
	GroupCommander:new({name='redcairointlPatrol', mission='patrol', targetzone='Cairo Intl'}),
	GroupCommander:new({name='redcairointlwadialjandaliAttack', mission='attack', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='redCairoIntlOvdaSupply', mission='supply', targetzone='Ovda'})
})

zones.cairowest:addGroups({
	GroupCommander:new({name='redcairowestwadialjandaliAttack', mission='attack', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='redcairowestcairointlAttack', mission='attack', targetzone='Cairo Intl'}),
	GroupCommander:new({name='redcairowestbilbeisAttack', mission='attack', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='redcairowestaburudeisAttack', mission='attack', targetzone='Abu Rudeis'}),
	GroupCommander:new({name='redcairoweststcatherineAttack', mission='attack', targetzone='St Catherine'}),
	GroupCommander:new({name='redcairowestcairointlAttack-1', mission='attack', targetzone='Cairo Intl', type='surface'}),
	GroupCommander:new({name='redCairoWestCairoIntlSupply', mission='supply', targetzone='Cairo Intl'}),
	GroupCommander:new({name='redCairoWestAlMansurahSupply', mission='supply', targetzone='Al Mansurah'}),
	GroupCommander:new({name='redCairoWestBileisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='redCairoWestWadiAlJandaliSupply', mission='supply', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='blueCairoWestAlMansurahSupply', mission='supply', targetzone='Al Mansurah'}),
	GroupCommander:new({name='blueCairoWestWadiAlJandaliSupply', mission='supply', targetzone='Wadi al Jandali'}),
	GroupCommander:new({name='blueCairoWestCairoIntlSupply', mission='supply', targetzone='Cairo Intl'}),
	GroupCommander:new({name='blueCairoWestBileisAirbaseSupply', mission='supply', targetzone='Bilbeis Air Base'}),
	GroupCommander:new({name='redCairoWestAbuRudeisSupply', mission='supply', targetzone='Abu Rudeis'}),
	GroupCommander:new({name='redcairowestPatrol', mission='patrol', targetzone='Cairo West'}),
	GroupCommander:new({name='redCairoWestMelezSupply', mission='supply', targetzone='Melez'}),
	GroupCommander:new({name='redCairoWestMelezAttack', mission='attack', targetzone='Melez'}),
	GroupCommander:new({name='redCairoWestWadiAlJandaliAttack', mission='attack', targetzone='Wadi al Jandali'})
})

zones.bengurion:addGroups({
	GroupCommander:new({name='blueBenGurionSdeDovSupply', mission='supply', targetzone='Sde Dov'}),
	GroupCommander:new({name='blueBenGurionPalmahimSupply', mission='supply', targetzone='Palmahim'}),
	GroupCommander:new({name='blueBenGurionTelNofSupply', mission='supply', targetzone='Tel Nof'}),
	GroupCommander:new({name='blueBenGurionHatzorSupply', mission='supply', targetzone='Hatzor'}),
	GroupCommander:new({name='blueBenGurionNevatimSupply', mission='supply', targetzone='Nevatim'})
})

--Critical objects


--adds visible lines of "connection" between related zones
for i,v in pairs(zones) do
	bc:addZone(v)
end

bc:addConnection("Ben-Gurion","Sde Dov")
bc:addConnection("Ben-Gurion","Palmahim")
bc:addConnection("Ben-Gurion","Tel Nof")
bc:addConnection("Ben-Gurion","Hatzor")
bc:addConnection("Ben-Gurion","Nevatim")
bc:addConnection("Nevatim","Sde Dov")
bc:addConnection("Nevatim","Palmahim")
bc:addConnection("Nevatim","Tel Nof")
bc:addConnection("Nevatim","Hatzor")
bc:addConnection("Nevatim","Ramon Airbase")
bc:addConnection("Nevatim","Ovda")
bc:addConnection("Ramon Airbase","Ovda")
bc:addConnection("Melez","Bir Hasanah")
bc:addConnection("Melez","Baluza")
bc:addConnection("Melez","Kibrit Air Base")
bc:addConnection("Melez","Ovda")
bc:addConnection("Melez","Ramon Airbase")
bc:addConnection("Camp X-Ray","St Catherine")
bc:addConnection("St Catherine","Abu Rudeis")
bc:addConnection("St Catherine","Camp X-Ray")
bc:addConnection("Kibrit Air Base","Abu Suwayr")
bc:addConnection("Kibrit Air Base","Bilbeis Air Base")
bc:addConnection("Kibrit Air Base","Wadi al Jandali")
bc:addConnection("Kibrit Air Base","Bir Hasanah")
bc:addConnection("Al Mansurah","As Salihiyah")
bc:addConnection("Al Mansurah","Bilbeis Air Base")
bc:addConnection("Al Mansurah","Cairo Intl")
bc:addConnection("Al Mansurah","Bilbeis Air Base")
bc:addConnection("Al Mansurah","Cairo West")
bc:addConnection("Al Mansurah","Baluza")
bc:addConnection("Cairo Intl","Ovda")
bc:addConnection("Cairo West","Cairo Intl")
bc:addConnection("Cairo West","Al Mansurah")
bc:addConnection("Cairo West","Bilbeis Air Base")
bc:addConnection("Cairo West","Wadi al Jandali")
bc:addConnection("Cairo West","Abu Rudeis")

--Mission complete msg
local checkMissionComplete = function (event, sender)
	local done = true
	for i,v in ipairs(bc:getZones()) do
		if v.side == 1 then
			done = false
			break
		end
	end
	
	if done then
		trigger.action.setUserFlag("ending", true)
		timer.scheduleFunction(endMission, {}, timer.getTime() + 20)
	end
end

for i,v in ipairs(bc:getZones()) do
	v:registerTrigger('lost', checkMissionComplete, 'missioncompleted')
end

--Disabling/losing zones (grayed out on map)


--F10 Menu Items
local upgradeMenu = nil
bc:registerShopItem('supplies', 'Resupply friendly Zone', 200, function(sender)
	if upgradeMenu then
		return 'Choose zone from F10 menu'
	end
	
	local upgradeZone = function(target)
		if upgradeMenu then
			local zn = bc:getZoneByName(target)
			if zn and zn.side==2 then
				zn:upgrade()
			else
				return 'Zone not friendly'
			end
			
			upgradeMenu = nil
		end
	end
	
	upgradeMenu = bc:showTargetZoneMenu(2, 'Select Zone to resupply', upgradeZone, 2)
	
	trigger.action.outTextForCoalition(2, 'Supplies prepared. Choose zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		params.zone:upgrade()
	else
		return 'Can only target friendly zone'
	end
end)

Group.getByName('capEast'):destroy()
bc:registerShopItem('capE', 'CAP East (F/A-18C)', 150, function(sender) 
	local grname = 'capEast'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

Group.getByName('capWest'):destroy()
bc:registerShopItem('capW', 'CAP West (F-15ESE)', 150, function(sender) 
	local grname = 'capWest'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('blueAWACSEast')
	if Utils.isGroupActive(gr) then 
		return 'Overlord still active on 350.00 MHz AM'
	end
	mist.respawnGroup('blueAWACSEast', true)
	trigger.action.outTextForCoalition(2,'Overlord active on 350.00 MHz AM',15)
end
Group.getByName('blueAWACSEast'):destroy()
bc:registerShopItem('AWACS East', 'AWACS East(E-3A)', 100, spawnAwacs, spawnAwacs)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('blueAWACSWest')
	if Utils.isGroupActive(gr) then 
		return 'Magic still active on 355.00 MHz AM'
	end
	mist.respawnGroup('blueAWACSWest', true)
	trigger.action.outTextForCoalition(2,'Magic active on 355.00 MHz AM',15)
end
Group.getByName('blueAWACSWest'):destroy()
bc:registerShopItem('AWACS West', 'AWACS West (E-3A)', 100, spawnAwacs, spawnAwacs)

local spawnTanker = function(sender) 
	local gr = Group.getByName('BlueTankerBoom')
	if Utils.isGroupActive(gr) then 
		return 'Boom Tanker still active on 351.00 MHz AM, feet wet, TACAN 25X'
	end
	mist.respawnGroup('BlueTankerBoom', true)
	trigger.action.outTextForCoalition(2,'Boom Tanker active on 352.00 MHz AM, feet wet, TACAN 25X',15)
end
Group.getByName('BlueTankerBoom'):destroy()
bc:registerShopItem('Boom Tanker', 'KC-135 Boom', 100, spawnTanker, spawnTanker)

local spawnTanker = function(sender) 
	local gr = Group.getByName('BlueTankerMPRS')
	if Utils.isGroupActive(gr) then 
		return 'MPRS Tanker still active on 352.00 MHz AM, feet wet, TACAN 30X'
	end
	mist.respawnGroup('BlueTankerMPRS', true)
	trigger.action.outTextForCoalition(2,'MPRS Tanker active on 355.00 MHz AM, feet wet, TACAN 30X',15)
end
Group.getByName('BlueTankerMPRS'):destroy()
bc:registerShopItem('MPRS Tanker', 'KC-135 MPRS', 100, spawnTanker, spawnTanker)

Group.getByName('casEast'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casE', 'CAS East (A-10CII)', 400, function(sender) 
	local gr = Group.getByName('casEast')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casEast', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casEast') then
				local err = bc:engageZone(target, 'casEast')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS East Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'A-10CII Warthogs on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casEast')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casEast', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casEast') then
				local err = bc:engageZone(target, 'casEast')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('casWest'):destroy()
local casTargetMenu = nil
bc:registerShopItem('casW', 'CAS West (A-10CII)', 400, function(sender) 
	local gr = Group.getByName('casWest')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('casWest', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('casWest') then
				local err = bc:engageZone(target, 'casWest')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS West Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'A-10CII Warthogs on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('casWest')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('casWest', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('casWest') then
				local err = bc:engageZone(target, 'casWest')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingEast'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombE', 'Bombing run East (F-15E)', 600, function(sender) 
	local gr = Group.getByName('bombingEast')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingEast', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingEast')
			if bomb then
				local err = bc:engageZone(target, 'bombingEast', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run East Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-15E Mudhen on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingEast')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingEast', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingEast')
			if bomb then
				local err = bc:engageZone(target, 'bombingEast', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('bombingWest'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bombW', 'Bombing run West (F-15E)', 600, function(sender) 
	local gr = Group.getByName('bombingWest')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('bombingWest', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('bombingWest')
			if bomb then
				local err = bc:engageZone(target, 'bombingWest', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run West Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-15E Mudhen on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('bombingWest')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('bombingWest', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('bombingWest')
			if bomb then
				local err = bc:engageZone(target, 'bombingWest', AI.Task.WeaponExpend.ONE)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadEast'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadE', 'SEAD East (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadEast')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadEast', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadEast') then
			local err = bc:engageZone(target, 'seadEast', AI.Task.WeaponExpend.TWO)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadEast')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadEast', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadEast') then
				local err = bc:engageZone(target, 'seadEast')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-a8c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('seadWest'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('seadW', 'SEAD West (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('seadWest')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('seadWest', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('seadWest') then
			local err = bc:engageZone(target, 'seadWest', AI.Task.WeaponExpend.TWO)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SAMs at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('seadWest')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('seadWest', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('seadWest') then
				local err = bc:engageZone(target, 'seadWest')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-a8c Hornets engaging SAMs at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('jtacDrone-Lase-1688'):destroy()
local jtacTargetMenu = nil
drone = JTAC:new({name = 'jtacDrone-Lase-1688'})
bc:registerShopItem('jtac', 'MQ-9 Reaper JTAC mission', 100, function(sender)
	
	if jtacTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local spawnAndOrbit = function(target)
		if jtacTargetMenu then
			local zn = bc:getZoneByName(target)
			drone:deployAtZone(zn)
			drone:showMenu()
			trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..target, 15)
			jtacTargetMenu = nil
		end
	end
	
	jtacTargetMenu = bc:showTargetZoneMenu(2, 'Deploy JTAC', spawnAndOrbit, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose which zone to deploy JTAC at from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		drone:deployAtZone(params.zone)
		drone:showMenu()
		trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

local smoketargets = function(tz)
	local units = {}
	for i,v in pairs(tz.built) do
		local g = Group.getByName(v)
		for i2,v2 in ipairs(g:getUnits()) do
			table.insert(units, v2)
		end
	end
	
	local tgts = {}
	for i=1,3,1 do
		if #units > 0 then
			local selected = math.random(1,#units)
			table.insert(tgts, units[selected])
			table.remove(units, selected)
		end
	end
	
	for i,v in ipairs(tgts) do
		local pos = v:getPosition().p
		trigger.action.smoke(pos, 1)
	end
end

local smokeTargetMenu = nil
bc:registerShopItem('smoke', 'Smoke markers', 20, function(sender)
	if smokeTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if smokeTargetMenu then
			local tz = bc:getZoneByName(target)
			smoketargets(tz)
			smokeTargetMenu = nil
			trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..target, 15)
		end
	end
	
	smokeTargetMenu = bc:showTargetZoneMenu(2, 'Smoke marker target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		smoketargets(params.zone)
		trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('Growler'):destroy()
local jamMenu = nil
bc:registerShopItem('jam', 'Jam radars at zone', 500, function(sender)
	local gr = Group.getByName('Growler')
	if Utils.isGroupActive(gr) then 
		return 'Jamming mission still in progress'
	end
	
	mist.respawnGroup('Growler', true)
	
	if jamMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local startJam = function(target)
		if jamMenu then
			bc:jamRadarsAtZone('Growler', target)
			jamMenu = nil
			trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
		end
	end
	
	jamMenu = bc:showTargetZoneMenu(2, 'Jamming target', startJam, 1)
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('Growler')
		if Utils.isGroupActive(gr) then 
			return 'Jamming mission still in progress'
		end
		
		mist.respawnGroup('Growler', true)
		
		mist.scheduleFunction(function(target)
			local ew = Group.getByName('Growler')
			if ew then
				local err = bc:jamRadarsAtZone('Growler', target)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
		
	else
		return 'Can only target enemy zone'
	end
end)

tanksMenu = nil
bc:registerShopItem('armor', 'Deploy armor (for combined arms)', 100, function(sender)
	
	if tanksMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployTanks = function(target)
		if tanksMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-tanks')
			
			tanksMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..target, 15)
		end
	end
	
	tanksMenu = bc:showTargetZoneMenu(2, 'Deploy armor (Choose friendly zone)', deployTanks, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-tanks')
		trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

artyMenu = nil
bc:registerShopItem('artillery', 'Deploy artillery (for combined arms)', 100, function(sender)
	
	if artyMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployArty = function(target)
		if artyMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-arty')
			
			artyMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..target, 15)
		end
	end
	
	artyMenu = bc:showTargetZoneMenu(2, 'Deploy artillery (Choose friendly zone)', deployArty, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-arty')
		trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

reconMenu = nil
bc:registerShopItem('recon', 'Deploy recon group (for combined arms)', 50, function(sender)
	
	if reconMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployRecon = function(target)
		if reconMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-recon')
			
			reconMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..target, 15)
		end
	end
	
	reconMenu = bc:showTargetZoneMenu(2, 'Deploy recon group (Choose friendly zone)', deployRecon, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-recon')
		trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

airdefMenu = nil
bc:registerShopItem('airdef', 'Deploy air defence (for combined arms)', 150, function(sender)
	
	if airdefMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployAirDef = function(target)
		if airdefMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-airdef')
			
			airdefMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..target, 15)
		end
	end
	
	airdefMenu = bc:showTargetZoneMenu(2, 'Deploy air defence (Choose friendly zone)', deployAirDef, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-airdef')
		trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

bc:addShopItem(2, 'supplies', -1)
bc:addShopItem(2, 'jtac', -1)
bc:addShopItem(2, 'smoke', -1)
bc:addShopItem(2, 'jam', -1)

bc:addShopItem(2, 'casE', -1)
bc:addShopItem(2, 'bombE', -1)
bc:addShopItem(2, 'capE', -1)
bc:addShopItem(2, 'AWACS East', -1)
bc:addShopItem(2, 'AWACS West', -1)
bc:addShopItem(2, 'Boom Tanker', -1)
bc:addShopItem(2, 'MPRS Tanker', -1)
bc:addShopItem(2, 'seadE', -1)
bc:addShopItem(2, 'seadW', -1)

bc:addShopItem(2, 'casW', -1)
bc:addShopItem(2, 'bombW', -1)
bc:addShopItem(2, 'capW', -1)

bc:addShopItem(2, 'armor', -1)
bc:addShopItem(2, 'artillery', -1)
bc:addShopItem(2, 'recon', -1)
bc:addShopItem(2, 'airdef', -1)

supplyZones = {
	'Ben-Gurion', 
	'Nevatim', 
	'Ramon Airbase', 
	'Melez',
	'Ovda',
	'Camp X-Ray',
	'St Catherine', 
	'Kibrit Air Base', 
	'Al Mansurah', 
	'Cairo West',
	'FARP Rome',
	'Carrier Group'
}

--logistics commander
lc = LogisticCommander:new({battleCommander = bc, supplyZones = supplyZones})
lc:init()

--Credit amounts for kills
bc:loadFromDisk() --will load and overwrite default zone levels, sides, funds and available shop items
bc:init()
bc:startRewardPlayerContribution(15,{infantry = 10, ground = 20, sam = 40, airplane = 50, ship = 250, helicopter=50, crate=200, rescue = 100})
HercCargoDropSupply.init(bc)

--GlobalSettings.defaultRespawns[1]['supply'] = { dead=60*60, hangar=30*60, preparing=5*60}
GlobalSettings.setDifficultyScaling(1.4,1)

--create event commander
evc = EventCommander:new({decissionFrequency=20*60, decissionVariance=15*60, skipChance = 5 }) --tried decissionFrequency=15*60, decissionVariance=15*60, skipChance = 5
evc:init()

--MIST spawns of events
evtmelezramonairbasearty = {
	['Melez'] = { 'evt-melez-ramonairbase-arty'}
}
for i,v in pairs(evtmelezramonairbasearty) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='ramonArtyAttack',
	action = function()
		for i,v in pairs(evtmelezramonairbasearty) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end --was 60, tried 85
		
		if bc:getZoneByName('Ramon Airbase').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(evtmelezramonairbasearty) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

evtCampXRayAttack = {
	['Melez'] = { 'evt-CampX-RayAttack'}
}
for i,v in pairs(evtCampXRayAttack) do
	for _,v2 in ipairs(v) do
		Group.getByName(v2):destroy()
	end
end
evc:addEvent({
	id='xrayArtyAttack',
	action = function()
		for i,v in pairs(evtCampXRayAttack) do
			if bc:getZoneByName(i).side == 1 then
				for _,v2 in ipairs(v) do
					mist.respawnGroup(v2, true)
				end
			end
		end
	end,
	canExecute = function()
		if math.random(1,100) < 60 then return false end --was 60, tried 85
		
		if bc:getZoneByName('Camp X-Ray').side ~= 2 then return false end
		
		local canAttack = false
		for i,v in pairs(evtCampXRayAttack) do
			if bc:getZoneByName(i).side == 1 then canAttack = true end
			
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return false end
			end
		end
		
		return canAttack
	end
})

Group.getByName('evt-bomber'):destroy()
evc:addEvent({
	id='bomb',
	action = function()
		mist.respawnGroup('evt-bomber', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return false end
		
		local triggers = {'Ramon Airbase'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startBomberAttack() -- called from bomber groups waypoint actions
	local tgts = {
		'Sde Dov',
		'Ben-Gurion',
		'Palmahim',
		'Tel Nof',
		'Hatzor',
		'Nevatim'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-bomber') then
			bc:engageZone(choice, 'evt-bomber',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-bomber-1'):destroy()
evc:addEvent({
	id='bomb1',
	action = function()
		mist.respawnGroup('evt-bomber-1', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-bomber-1')
		if gr then return false end
		
		local triggers = {'St Catherine', 'Ovda'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startBomberAttack1() -- called from bomber groups waypoint actions
	local tgts = {
		'St Catherine',
		'Ovda'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-bomber-1') then
			bc:engageZone(choice, 'evt-bomber-1',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-bomber-2'):destroy()
evc:addEvent({
	id='bomb2',
	action = function()
		mist.respawnGroup('evt-bomber-2', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-bomber-2')
		if gr then return false end
		
		local triggers = {'Kibrit Air Base', 'Melez', 'Bir Hasanah'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startBomberAttack2() -- called from bomber groups waypoint actions
	local tgts = {
		'Kibrit Air Base',
		'Melez',
		'Bir Hasanah'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-bomber-2') then
			bc:engageZone(choice, 'evt-bomber-2',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas'):destroy()
evc:addEvent({
	id='cas',
	action = function()
		mist.respawnGroup('evt-cas', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas')
		if gr then return false end
		
		local triggers = {'Hatzor', 'Nevatim', 'Ramon Airbase'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCASAttack() -- called from CAS groups waypoint actions
	local tgts = {
		'Ben-Gurion',
		'Hatzor',
		'Nevatim',
		'Ramon Airbase'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas') then
			bc:engageZone(choice, 'evt-cas',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas-1'):destroy()
evc:addEvent({
	id='cas1',
	action = function()
		mist.respawnGroup('evt-cas-1', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas-1')
		if gr then return false end
		
		local triggers = {'Melez', 'Bir Hasanah', 'Kibrit Air Base'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCAS1Attack() -- called from CAS1 groups waypoint actions
	local tgts = {
		'Kibrit Air Base',
		'Melez',
		'Bir Hasanah'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas-1') then
			bc:engageZone(choice, 'evt-cas-1',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-carrierAttack'):destroy()
evc:addEvent({
	id='carrierAttack',
	action = function()
		mist.respawnGroup('evt-carrierAttack', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-carrierAttack')
		if gr then return false end
		
		local triggers = {'Carrier Group'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCarrierAttack() -- called from carrierAttack groups waypoint actions
	local tgts = {
		'Carrier Group'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-carrierAttack') then
			bc:engageZone(choice, 'evt-carrierAttack',  AI.Task.WeaponExpend.ALL)
		end
	end
end

-- System msgs for events triggered
mc = MissionCommander:new({side = 2, battleCommander = bc, checkFrequency = 45}) --was checkFrequency = 60, then 20
mc:trackMission({
	title = "Defend Ramon Airbase",
	description = "The enemy is preparing an attack on Ramon Airbase.",
	messageStart = "New mission: Defend Ramon Airbase",
	messageEnd = "Mission ended: Defend Ramon Airbase",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(evtmelezramonairbasearty) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Defend Camp X-Ray",
	description = "The enemy is preparing an attack on Camp-X-Ray.",
	messageStart = "New mission: Defend Camp X-Ray",
	messageEnd = "Mission ended: Defend Camp X-Ray",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		for i,v in pairs(evtCampXRayAttack) do
			for _,v2 in ipairs(v) do
				if Group.getByName(v2) then return true end
			end
		end
		
		return false
	end
})

mc:trackMission({
	title = "Intercept Bombers",
	description = "Enemy bombers spotted to the East\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept East Bombers",
	messageEnd = "Mission ended: Intercept East Bombers",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept Bombers1",
	description = "Enemy bombers spotted to the South-West\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept South-West Bombers",
	messageEnd = "Mission ended: Intercept South-West Bombers",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-bomber-1')
		if gr then return true else return false end
	end
})
mc:trackMission({
	title = "Intercept Bombers2",
	description = "Enemy bombers spotted to the North-West\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept North-West Bombers",
	messageEnd = "Mission ended: Intercept North-West Bombers",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-bomber-2')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the West\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy North-East CAS airstrike",
	messageEnd = "Mission ended: Intercept enemy North-East CAS airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the South\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy South-West CAS airstrike",
	messageEnd = "Mission ended: Intercept enemy South-West CAS airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas-1')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept Carrier Strike",
	description = "Enemy aircraft conducting an airstrike on the Carrier Group\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept Carrier Group airstrike",
	messageEnd = "Mission ended: Intercept Carrier Group airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-carrierAttack')
		if gr then return true else return false end
	end
})

resupplyTarget = nil
mc:trackMission({
	title = function() return "Resupply "..resupplyTarget end,
	description = function() return "Deliver supplies to "..resupplyTarget end,
	messageStart = function() return "New mission: Resupply "..resupplyTarget end,
	messageEnd = function() return "Mission ended: Resupply "..resupplyTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		resupplyTarget = nil
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not resupplyTarget then return false end
		
		local targetzn = bc:getZoneByName(resupplyTarget)
		return targetzn:canRecieveSupply()
	end
})

attackTarget = nil
mc:trackMission({
	title = function() return "Attack "..attackTarget end,
	description = function() return "Destroy enemy forces at "..attackTarget end,
	messageStart = function() return "New mission: Attack "..attackTarget end,
	messageEnd = function() return "Mission ended: Attack "..attackTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		attackTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not attackTarget then return false end
		
		local targetzn = bc:getZoneByName(attackTarget)
		return targetzn.side == 1
	end
})

captureTarget = nil
mc:trackMission({
	title = function() return "Capture "..captureTarget end,
	description = function() return captureTarget.." is neutral. Capture it by delivering supplies" end,
	messageStart = function() return "New mission: Capture "..captureTarget end,
	messageEnd = function() return "Mission ended: Capture "..captureTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		captureTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not captureTarget then return false end
		
		local targetzn = bc:getZoneByName(captureTarget)
		return targetzn.side == 0 and targetzn.active
	end
})

--Functions/

--function addFunds250()
	--bc:addFunds(2,250)
	--end
	
--function addFunds500()
	--bc:addFunds(2,500)
	--end
	
function addSpecialFunds500()
	bc:addFunds(2,500)
	end
	
--function addRestartCredits()
	--bc:addFunds(2,1500)
	--end
	
	
function endMission()
	--trigger.action.outTextForCoalition(2, 'file path is '..pathofFile, 420)
	--io.close(pathofFile)
	--timer.scheduleFunction(delFile, {}, timer.getTime() + 10)
	--os.remove(pathofFile)
	trigger.action.setUserFlag("endMission", true)
	end
	
function generateCaptureMission()
	if captureTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 0 and v.active and v.zone ~= "FARP Rome" then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		captureTarget = validzones[choice]
		return true
	end
end

function generateAttackMission()
	if attackTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.connections) do
		local to = bc:getZoneByName(v.to)
		local from = bc:getZoneByName(v.from)
		
		if from.side ~= to.side and from.side ~= 0  and to.side ~= 0 and from.active and to.active then
			if from.side == 1 then
				table.insert(validzones, from.zone)
			elseif to.side == 1 then
				table.insert(validzones, to.zone)
			end
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		attackTarget = validzones[choice]
		return true
	end
end

function generateSupplyMission()
	if resupplyTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 2 and v:canRecieveSupply() then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		resupplyTarget = validzones[choice]
		return true
	end
end

timer.scheduleFunction(function(_, time)
	if generateCaptureMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 20)

timer.scheduleFunction(function(_, time)
	if generateAttackMission() then
		return time+1500  --was 300, 600, 900
	else
		return time+1500  --was 120, 300, 600
	end
end, {}, timer.getTime() + 40)

timer.scheduleFunction(function(_, time)
	if generateSupplyMission() then
		return time+600  -- was 480
	else
		return time+450  --was 240, 360
	end
end, {}, timer.getTime() + 60)

mc:init()